@@ -9,7 +9,6 @@ use base qw/Data::ICal::Entry/;
 
 Data::ICal::Entry::Todo - Represents a to-do entry in an iCalendar file
 
-
 =head1 SYNOPSIS
 
     my $vtodo = Data::ICal::Entry::Todo->new();
@@ -23,12 +22,13 @@ Data::ICal::Entry::Todo - Represents a to-do entry in an iCalendar file
     $calendar->add_entry($vtodo);
 
     $vtodo->add_entry($alarm); 
-  
+
 =head1 DESCRIPTION
 
-A L<Data::ICal::Entry::Todo> object represents a single to-do entry in an iCalendar file.
-(Note that the iCalendar RFC refers to entries as "components".)  It is a subclass
-of L<Data::ICal::Entry> and accepts all of its methods.
+A L<Data::ICal::Entry::Todo> object represents a single to-do entry in
+an iCalendar file.  (Note that the iCalendar RFC refers to entries as
+"components".)  It is a subclass of L<Data::ICal::Entry> and accepts
+all of its methods.
 
 =head1 METHODS
 
@@ -44,16 +44,17 @@ sub ical_entry_type {'VTODO'}
 
 =head2 optional_unique_properties
 
-According to the iCalendar standard, the following properties may be specified
-at most one time for a to-do item:
+According to the iCalendar standard, the following properties may be
+specified at most one time for a to-do item:
 
       class  completed  created  description  dtstamp
       dtstart  geo  last-modified  location  organizer
       percent-complete  priority  recurrence-id  sequence  status
       summary  uid  url
 
-In addition, C<due> and C<duration> may be specified at most once each, but not both
-in the same entry (though this restriction is not enforced).
+In addition, C<due> and C<duration> may be specified at most once
+each, but not both in the same entry (though this restriction is not
+enforced).
 
 =cut
 
@@ -70,8 +71,8 @@ sub optional_unique_properties {
 
 =head2 optional_repeatable_properties
 
-According to the iCalendar standard, the following properties may be specified
-any number of times for a to-do item:
+According to the iCalendar standard, the following properties may be
+specified any number of times for a to-do item:
 
       attach  attendee  categories  comment  contact
       exdate  exrule  request-status  related-to  resources
@@ -89,12 +90,12 @@ sub optional_repeatable_properties {
 
 =head1 AUTHOR
 
-Jesse Vincent  C<< <jesse@bestpractical.com> >> with David Glasser and Simon Wistow
-
+Jesse Vincent C<< <jesse@bestpractical.com> >> with David Glasser,
+Simon Wistow, and Alex Vandiver
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, Best Practical Solutions, LLC.  All rights reserved.
+Copyright (c) 2005 - 2009, Best Practical Solutions, LLC.  All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
